@@ -4,9 +4,6 @@ kombu.exceptions
 
 Exceptions.
 
-:copyright: (c) 2009 - 2012 by Ask Solem.
-:license: BSD, see LICENSE for more details.
-
 """
 from __future__ import absolute_import
 
@@ -14,8 +11,8 @@ import socket
 
 __all__ = ['NotBoundError', 'MessageStateError', 'TimeoutError',
            'LimitExceeded', 'ConnectionLimitExceeded',
-           'ChannelLimitExceeded', 'StdChannelError', 'VersionMismatch',
-           'SerializerNotInstalled']
+           'ChannelLimitExceeded', 'StdConnectionError',
+           'StdChannelError', 'VersionMismatch', 'SerializerNotInstalled']
 
 TimeoutError = socket.timeout
 
@@ -49,6 +46,10 @@ class ChannelLimitExceeded(LimitExceeded):
     pass
 
 
+class StdConnectionError(KombuError):
+    pass
+
+
 class StdChannelError(KombuError):
     pass
 
@@ -62,7 +63,7 @@ class SerializerNotInstalled(KombuError):
     pass
 
 
-class InconsistencyError(StdChannelError):
+class InconsistencyError(StdConnectionError):
     """Data or environment has been found to be inconsistent,
     depending on the cause it may be possible to retry the operation."""
     pass
